<?php
// check_errors.php - Скрипт для диагностики ошибок 500

echo "<h1>🔍 Диагностика ошибки 500</h1>";

// Включаем отображение всех ошибок
error_reporting(E_ALL);
ini_set('display_errors', 1);

echo "<h2>📋 Основная информация</h2>";
echo "PHP версия: " . PHP_VERSION . "<br>";
echo "Время сервера: " . date('Y-m-d H:i:s') . "<br>";
echo "Рабочая директория: " . getcwd() . "<br><br>";

// Проверяем права доступа
echo "<h2>🔐 Права доступа</h2>";
$files_to_check = ['webhook.php', 'config.php', 'functions.php', '.'];
foreach ($files_to_check as $file) {
    if (file_exists($file)) {
        $perms = fileperms($file);
        $perms_string = substr(sprintf('%o', $perms), -4);
        $readable = is_readable($file) ? '✅' : '❌';
        $writable = is_writable($file) ? '✅' : '❌';
        echo "$file: права $perms_string, читается $readable, записывается $writable<br>";
    } else {
        echo "$file: ❌ не существует<br>";
    }
}

// Создаем debug.log если не существует
if (!file_exists('debug.log')) {
    file_put_contents('debug.log', date('Y-m-d H:i:s') . " - Debug log created\n");
}

echo "<br>";

// Проверяем существование файлов
echo "<h2>📁 Файлы</h2>";
$required_files = ['webhook.php', 'config.php', 'functions.php'];
foreach ($required_files as $file) {
    if (file_exists($file)) {
        $size = filesize($file);
        echo "✅ $file (размер: $size байт)<br>";
    } else {
        echo "❌ $file - НЕ НАЙДЕН<br>";
    }
}

echo "<br>";

// Проверяем синтаксис файлов
echo "<h2>🔧 Проверка синтаксиса</h2>";
foreach ($required_files as $file) {
    if (file_exists($file)) {
        $output = [];
        $return_var = 0;
        exec("php -l $file 2>&1", $output, $return_var);
        
        if ($return_var === 0) {
            echo "✅ $file - синтаксис корректен<br>";
        } else {
            echo "❌ $file - ошибка синтаксиса:<br>";
            echo "<pre>" . implode("\n", $output) . "</pre>";
        }
    }
}

echo "<br>";

// Пытаемся подключить config.php
echo "<h2>⚙️ Проверка config.php</h2>";
try {
    require_once 'config.php';
    echo "✅ config.php подключен успешно<br>";
    
    // Проверяем константы
    $constants = ['BOT_TOKEN', 'DB_HOST', 'DB_NAME', 'DB_USER', 'DB_PASS'];
    foreach ($constants as $const) {
        if (defined($const)) {
            $value = constant($const);
            if ($const === 'BOT_TOKEN' || $const === 'DB_PASS') {
                $value = substr($value, 0, 10) . '...'; // Маскируем чувствительные данные
            }
            echo "✅ $const = $value<br>";
        } else {
            echo "❌ $const не определена<br>";
        }
    }
} catch (Exception $e) {
    echo "❌ Ошибка подключения config.php: " . $e->getMessage() . "<br>";
} catch (ParseError $e) {
    echo "❌ Синтаксическая ошибка в config.php: " . $e->getMessage() . "<br>";
}

echo "<br>";

// Пытаемся подключить functions.php
echo "<h2>🔧 Проверка functions.php</h2>";
try {
    require_once 'functions.php';
    echo "✅ functions.php подключен успешно<br>";
    
    // Проверяем функции
    $functions = ['db', 'create_directories', 'is_admin'];
    foreach ($functions as $func) {
        if (function_exists($func)) {
            echo "✅ Функция $func существует<br>";
        } else {
            echo "❌ Функция $func не найдена<br>";
        }
    }
} catch (Exception $e) {
    echo "❌ Ошибка подключения functions.php: " . $e->getMessage() . "<br>";
} catch (ParseError $e) {
    echo "❌ Синтаксическая ошибка в functions.php: " . $e->getMessage() . "<br>";
}

echo "<br>";

// Проверяем подключение к базе данных
echo "<h2>🗄️ Проверка базы данных</h2>";
if (defined('DB_HOST') && defined('DB_USER') && defined('DB_PASS') && defined('DB_NAME')) {
    try {
        $conn = new mysqli(DB_HOST, DB_USER, DB_PASS, DB_NAME);
        if ($conn->connect_error) {
            echo "❌ Ошибка подключения: " . $conn->connect_error . "<br>";
        } else {
            echo "✅ Подключение к MySQL успешно<br>";
            echo "✅ База данных: " . DB_NAME . "<br>";
            
            // Проверяем таблицы
            $tables = ['users', 'profiles', 'bets'];
            foreach ($tables as $table) {
                $result = $conn->query("SHOW TABLES LIKE '$table'");
                if ($result && $result->num_rows > 0) {
                    echo "✅ Таблица $table существует<br>";
                } else {
                    echo "⚠️ Таблица $table не найдена<br>";
                }
            }
            $conn->close();
        }
    } catch (Exception $e) {
        echo "❌ Исключение при подключении к БД: " . $e->getMessage() . "<br>";
    }
} else {
    echo "❌ Настройки БД не определены<br>";
}

echo "<br>";

// Проверяем PHP модули
echo "<h2>🐘 PHP модули</h2>";
$required_modules = ['mysqli', 'json', 'curl'];
foreach ($required_modules as $module) {
    if (extension_loaded($module)) {
        echo "✅ $module загружен<br>";
    } else {
        echo "❌ $module НЕ загружен<br>";
    }
}

echo "<br>";

// Проверяем логи ошибок
echo "<h2>📝 Логи ошибок</h2>";

// PHP error log
$php_error_log = ini_get('error_log');
if ($php_error_log && file_exists($php_error_log)) {
    echo "📄 PHP error log: $php_error_log<br>";
    $last_errors = tail_file($php_error_log, 5);
    if ($last_errors) {
        echo "<strong>Последние ошибки:</strong><br>";
        echo "<pre>$last_errors</pre>";
    }
} else {
    echo "⚠️ PHP error log не найден<br>";
}

// Apache error log (обычные пути)
$apache_logs = [
    '/var/log/apache2/error.log',
    '/var/log/httpd/error_log',
    '/usr/local/apache2/logs/error_log'
];

foreach ($apache_logs as $log) {
    if (file_exists($log) && is_readable($log)) {
        echo "📄 Apache error log: $log<br>";
        $last_errors = tail_file($log, 5);
        if ($last_errors) {
            echo "<strong>Последние ошибки Apache:</strong><br>";
            echo "<pre>$last_errors</pre>";
        }
        break;
    }
}

// Наш debug.log
if (file_exists('debug.log')) {
    echo "📄 Debug log:<br>";
    $debug_content = file_get_contents('debug.log');
    echo "<pre>$debug_content</pre>";
} else {
    echo "⚠️ debug.log не найден<br>";
}

echo "<br>";

// Тест webhook
echo "<h2>🧪 Тест webhook</h2>";
echo "<p>Для тестирования webhook выполните:</p>";
echo "<code>curl -X POST https://" . $_SERVER['HTTP_HOST'] . dirname($_SERVER['REQUEST_URI']) . "/webhook.php -d '{\"message\":{\"chat\":{\"id\":123},\"from\":{\"id\":123,\"first_name\":\"Test\"},\"text\":\"/test\"}}'</code><br><br>";

// Кнопка для тестирования
echo "<button onclick=\"testWebhook()\">🧪 Протестировать webhook</button><br>";

echo "<script>
function testWebhook() {
    fetch('webhook.php', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify({
            message: {
                chat: {id: 123, type: 'private'},
                from: {id: 123, first_name: 'Test'},
                text: '/test'
            }
        })
    })
    .then(response => response.text())
    .then(data => {
        alert('Ответ webhook: ' + data);
        location.reload(); // Обновляем страницу чтобы увидеть новые логи
    })
    .catch(error => {
        alert('Ошибка: ' + error);
    });
}
</script>";

echo "<hr>";
echo "<p>🔄 <a href='?'>Обновить диагностику</a></p>";
echo "<p>📋 <a href='debug.log'>Открыть debug.log</a></p>";

// Функция для чтения последних строк файла
function tail_file($filename, $lines = 10) {
    if (!file_exists($filename) || !is_readable($filename)) {
        return false;
    }
    
    $handle = fopen($filename, "r");
    if (!$handle) return false;
    
    $linecounter = $lines;
    $pos = -2;
    $beginning = false;
    $text = array();
    
    while ($linecounter > 0) {
        $t = " ";
        while ($t != "\n") {
            if (fseek($handle, $pos, SEEK_END) == -1) {
                $beginning = true;
                break;
            }
            $t = fgetc($handle);
            $pos--;
        }
        $linecounter--;
        if ($beginning) {
            rewind($handle);
        }
        $text[$lines - $linecounter - 1] = fgets($handle);
        if ($beginning) break;
    }
    fclose($handle);
    return implode("", array_reverse($text));
}
?>